@@ -188,8 +188,11 @@ class ClickSign:
         return True
 
     #region ### Document Methods ###
-    def create_new_doc_from_template(self, template_key: str, doc_path: str,
-                                     data: Dict, auto_close=True) -> Document:
+    def create_new_doc_from_template(self,
+                                     template_key: str,
+                                     doc_path: str,
+                                     data: Dict,
+                                     auto_close=True) -> Document:
         """Create a new document from a template.
         Args:
             template_key (str): The template key that you want to use as base document.
@@ -212,11 +215,17 @@ class ClickSign:
             ".docx") else f'{doc_path}.docx'
 
         if auto_close:
-            body = {'document': {'path': doc_path,
-                                 'template': {'data': data}}}
+            body = {'document': {'path': doc_path, 'template': {'data': data}}}
         else:
-            body = {'document': {'path': doc_path, 'template': {
-                'data': data}, 'auto_close': auto_close}}
+            body = {
+                'document': {
+                    'path': doc_path,
+                    'template': {
+                        'data': data
+                    },
+                    'auto_close': auto_close
+                }
+            }
 
         resp = make_response(
             method="POST",
@@ -227,6 +236,53 @@ class ClickSign:
         metadata = resp.json()
         return Document(self, metadata)
 
+    def create_new_doc_uploading_file(self,
+                                      content_base64: str,
+                                      doc_path: str,
+                                      auto_close: bool = True) -> Document:
+        """Create a new document from a file.
+        Args:
+            content_base64 (str): The file encoded in base64 with the mimetype Ex: 'data:<mimetype>;base64,<data>' The mimetype of the file. Should be in [application/pdf, application/msword, application/vnd.openxmlformats-officedocument.wordprocessingml.document] 
+            doc_path (str): The new document path (folder location and file name)
+            auto_close (bool): If the document should be closed automatically
+        Raises:
+            BadRequest: Bad request, check your request
+            Unauthorized: Invalid token
+            Forbidden: You do not have permition to this resource. 
+            NotFound: Resource not found. Check the endpoint
+            UnProcessableEntity: The server was unable to process the request
+            UnknownServerError: Internal server error
+        Returns:
+            Document: The new Document with all custom data provide. 
+        """
+
+        # Add / to begin of doc_path
+        doc_path = doc_path if doc_path.startswith("/") else f'/{doc_path}'
+
+        if auto_close:
+            body = {
+                "document": {
+                    'path': doc_path,
+                    'content_base64': content_base64
+                }
+            }
+        else:
+            body = {
+                "document": {
+                    'path': doc_path,
+                    'content_base64': content_base64,
+                    'auto_close': auto_close
+                }
+            }
+
+        resp = make_response(method="POST",
+                             url=self.__url('documents'),
+                             json=body,
+                             params=self.query_string,
+                             timeout=self.timeout)
+        metadata = resp.json()
+        return Document(self, metadata)
+
     def config_doc(self, document_key: str, **kwargs) -> Document:
         """Use the configure a document.
         Args:
